@@ -48,7 +48,7 @@
 
 #include "bctoolbox/crypto.h"
 #include "bctoolbox/logging.h"
-
+#include "bctoolbox/defs.h"
 
 /*** Cleaning ***/
 /**
@@ -848,6 +848,7 @@ bctbx_ssl_context_t *bctbx_ssl_context_new(void) {
 }
 
 void bctbx_ssl_context_free(bctbx_ssl_context_t *ssl_ctx) {
+	if (ssl_ctx == NULL) return;
 	mbedtls_ssl_free(&(ssl_ctx->ssl_ctx));
 	bctbx_free(ssl_ctx);
 }
@@ -903,8 +904,10 @@ int32_t bctbx_ssl_handshake(bctbx_ssl_context_t *ssl_ctx) {
 
 				if (ssl_ctx->callback_cli_cert_function(ssl_ctx->callback_cli_cert_data, ssl_ctx, names)!=0) {
 					bctbx_list_free_with_data(names, bctbx_free);
-					if((ret=mbedtls_ssl_send_alert_message(&(ssl_ctx->ssl_ctx), MBEDTLS_SSL_ALERT_LEVEL_FATAL, MBEDTLS_SSL_ALERT_MSG_HANDSHAKE_FAILURE)) != 0 )
+					if((ret=mbedtls_ssl_send_alert_message(&(ssl_ctx->ssl_ctx), MBEDTLS_SSL_ALERT_LEVEL_FATAL, MBEDTLS_SSL_ALERT_MSG_HANDSHAKE_FAILURE)) != 0 ) {
 						return( ret );
+					}
+					return BCTBX_ERROR_NO_CLIENT_CERTIFICATE;
 				}
 				bctbx_list_free_with_data(names, bctbx_free);
 			}
@@ -1327,7 +1330,7 @@ int32_t bctbx_ssl_config_set_own_cert(bctbx_ssl_config_t *ssl_config, bctbx_x509
 /* This callback is executed during the DTLS handshake, extract the master secret and randoms needed to generate the DTLS-SRTP keys
  * The generation itself is performed after the handshake */
 static int bctbx_ssl_dtls_srtp_key_derivation(void *key_ctx, const unsigned char *ms,
-		const unsigned char *kb, size_t maclen, size_t keylen, size_t ivlen, // these params are useless for our purpose
+		BCTBX_UNUSED(const unsigned char * kb), BCTBX_UNUSED(size_t maclen), BCTBX_UNUSED(size_t keylen), BCTBX_UNUSED(size_t ivlen), // these params are useless for our purpose
 		const unsigned char client_random[32], const unsigned char server_random[32],
 		mbedtls_tls_prf_types tls_prf_type ) {
 
