@@ -32,8 +32,7 @@
 #include <mbedtls/hkdf.h> // HKDF implemented in version 2.11.0 of mbedtls
 #endif
 
-
-
+#include "bctoolbox/defs.h"
 #include "bctoolbox/crypto.hh"
 #include "bctoolbox/crypto.h"
 #include "bctoolbox/exception.hh"
@@ -132,7 +131,7 @@ uint32_t RNG::cRandomize() {
 /* HMAC templates */
 /* HMAC must use a specialized template */
 template <typename hashAlgo>
-std::vector<uint8_t> HMAC(const std::vector<uint8_t> &key, const std::vector<uint8_t> &input) {
+std::vector<uint8_t> HMAC(BCTBX_UNUSED(const std::vector<uint8_t> &key), BCTBX_UNUSED(const std::vector<uint8_t> &input)) {
 	/* if this template is instanciated the static_assert will fail but will give us an error message */
 	static_assert(sizeof(hashAlgo) != sizeof(hashAlgo), "You must specialize HMAC function template");
 	return std::vector<uint8_t>(0);
@@ -170,13 +169,13 @@ template <> std::vector<uint8_t> HMAC<SHA512>(const std::vector<uint8_t> &key, c
 /* HKDF templates */
 /* HKDF must use a specialized template */
 template <typename hashAlgo>
-std::vector<uint8_t> HKDF(const std::vector<uint8_t> &salt, const std::vector<uint8_t> &ikm, const std::vector<uint8_t> &info, size_t okmSize) {
+std::vector<uint8_t> HKDF(BCTBX_UNUSED(const std::vector<uint8_t> &salt), BCTBX_UNUSED(const std::vector<uint8_t> &ikm), BCTBX_UNUSED(const std::vector<uint8_t> &info), BCTBX_UNUSED(size_t okmSize)) {
 	/* if this template is instanciated the static_assert will fail but will give us an error message */
 	static_assert(sizeof(hashAlgo) != sizeof(hashAlgo), "You must specialize HKDF function template");
 	return std::vector<uint8_t>(0);
 }
 template <typename hashAlgo>
-std::vector<uint8_t> HKDF(const std::vector<uint8_t> &salt, const std::vector<uint8_t> &ikm, const std::string &info, size_t okmSize) {
+std::vector<uint8_t> HKDF(BCTBX_UNUSED(const std::vector<uint8_t> &salt), BCTBX_UNUSED(const std::vector<uint8_t> &ikm), BCTBX_UNUSED(const std::string &info), BCTBX_UNUSED(size_t okmSize)) {
 	/* if this template is instanciated the static_assert will fail but will give us an error message */
 	static_assert(sizeof(hashAlgo) != sizeof(hashAlgo), "You must specialize HKDF function template");
 
@@ -293,16 +292,16 @@ template <> std::vector<uint8_t> HKDF<SHA512>(const std::vector<uint8_t> &salt,
 /*****************************************************************************/
 /* AEAD template must be specialized */
 template <typename AEADAlgo>
-std::vector<uint8_t> AEADEncrypt(const std::vector<uint8_t> &key, const std::vector<uint8_t> IV, const std::vector<uint8_t> &plain, const std::vector<uint8_t> &AD,
-		std::vector<uint8_t> &tag) {
+std::vector<uint8_t> AEADEncrypt(BCTBX_UNUSED(const std::vector<uint8_t> &key), BCTBX_UNUSED(const std::vector<uint8_t> IV), BCTBX_UNUSED(const std::vector<uint8_t> &plain), BCTBX_UNUSED(const std::vector<uint8_t> &AD),
+		BCTBX_UNUSED(std::vector<uint8_t> &tag)) {
 	/* if this template is instanciated the static_assert will fail but will give us an error message with faulty type */
 	static_assert(sizeof(AEADAlgo) != sizeof(AEADAlgo), "You must specialize AEADEncrypt function template");
 	return std::vector<uint8_t>(0);
 }
 
 template <typename AEADAlgo>
-bool AEADDecrypt(const std::vector<uint8_t> &key, const std::vector<uint8_t> &IV, const std::vector<uint8_t> &cipher, const std::vector<uint8_t> &AD,
-		const std::vector<uint8_t> &tag, std::vector<uint8_t> &plain) {
+bool AEADDecrypt(BCTBX_UNUSED(const std::vector<uint8_t> &key), BCTBX_UNUSED(const std::vector<uint8_t> &IV), BCTBX_UNUSED(const std::vector<uint8_t> &cipher), BCTBX_UNUSED(const std::vector<uint8_t> &AD),
+		BCTBX_UNUSED(const std::vector<uint8_t> &tag), BCTBX_UNUSED(std::vector<uint8_t> &plain)) {
 	/* if this template is instanciated the static_assert will fail but will give us an error message with faulty type */
 	static_assert(sizeof(AEADAlgo) != sizeof(AEADAlgo), "You must specialize AEADEncrypt function template");
 	return false;
@@ -559,21 +558,19 @@ int AES_key_unwrap(const std::vector<uint8_t> &ciphertext, const std::vector<uin
 
 /*** Random Number Generation: C API ***/
 struct bctbx_rng_context_struct {
-	std::unique_ptr<bctoolbox::RNG> m_rng; // encapsulate the RNG in a unique_ptr
+	bctoolbox::RNG m_rng;
 };
 
 bctbx_rng_context_t *bctbx_rng_context_new(void) {
 	bctbx_rng_context_t *context = new bctbx_rng_context_struct();
-	context->m_rng = std::unique_ptr<bctoolbox::RNG>(new bctoolbox::RNG());
 	return context;
 }
 
 int32_t bctbx_rng_get(bctbx_rng_context_t *context, unsigned char*output, size_t output_length) {
-	context->m_rng->randomize(output, output_length);
+	context->m_rng.randomize(output, output_length);
 	return 0; // always return 0, in case of problem an exception is raised by randomize
 }
 
 void bctbx_rng_context_free(bctbx_rng_context_t *context) {
-	context->m_rng=nullptr; // destroy the RNG
-	delete(context);
+	delete context;
 }
