@@ -24,6 +24,7 @@
 #include <bctoolbox/logging.h>
 #include <bctoolbox/tester.h>
 #include <bctoolbox/vfs.h>
+#include <bctoolbox/defs.h>
 
 #include <stdlib.h>
 #include <time.h>
@@ -142,7 +143,7 @@ void bc_tester_set_process_events_func(void (*func)(void)) {
 	process_events = func;
 }
 
-void bc_tester_process_events(){
+void bc_tester_process_events(void){
 	if( process_events)
 		process_events();
 }
@@ -401,7 +402,7 @@ void merge_and_print_results_files(void) {
 	}
 }
 
-static void all_complete_message_handler(const CU_pFailureRecord pFailure) {
+static void all_complete_message_handler(BCTBX_UNUSED(const CU_pFailureRecord pFailure)) {
 #ifdef HAVE_CU_GET_SUITE
 	if (run_in_parallel != 0) {
 		if (suite_name) {
@@ -434,7 +435,7 @@ static void suite_start_message_handler(const CU_pSuite pSuite) {
 	suite_start_time = bctbx_get_cur_time_ms();
 	bc_current_suite_name = pSuite->pName;
 }
-static void suite_complete_message_handler(const CU_pSuite pSuite, const CU_pFailureRecord pFailure) {
+static void suite_complete_message_handler(const CU_pSuite pSuite, BCTBX_UNUSED(const CU_pFailureRecord pFailure)) {
 	bc_tester_printf(bc_printf_verbosity_info, "Suite [%s] ended in %.3f sec\n", pSuite->pName,
 			 (bctbx_get_cur_time_ms() - suite_start_time) / 1000.f);
 }
@@ -575,7 +576,7 @@ void merge_junit_xml_files(const char *dst_file_name) {
 		offset = bctbx_file_fprintf(bctbx_file, 0, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<testsuites>\n");
 		for (i = 0; i < nb_test_suites; i++) {
 			if (suite_junit_xml_results[i] != NULL) {
-				offset += bctbx_file_fprintf(bctbx_file, offset, suite_junit_xml_results[i]);
+				offset += bctbx_file_fprintf(bctbx_file, offset, "%s", suite_junit_xml_results[i]);
 				bctbx_free(suite_junit_xml_results[i]);
 			}
 		}
@@ -1203,13 +1204,13 @@ static void detect_res_prefix(const char* prog) {
 }
 
 //Default function for the `--verbose`cli option
-int bc_tester_verbose_handler(const char *arg) {
+int bc_tester_verbose_handler(BCTBX_UNUSED(const char * arg)) {
 	bctbx_set_log_level(BCTBX_LOG_DOMAIN, BCTBX_LOG_DEBUG);
 	return 0;
 }
 
 //Default function for the `--silent` cli option
-int bc_tester_silent_handler(const char *arg) {
+int bc_tester_silent_handler(BCTBX_UNUSED(const char *arg)) {
 	bctbx_set_log_level(BCTBX_LOG_DOMAIN, BCTBX_LOG_FATAL);
 	return 0;
 }
@@ -1254,6 +1255,10 @@ void bc_tester_init(void (*ftester_printf)(int level, const char *format, va_lis
 	}
 }
 
+#ifndef _MSC_VER
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif // _MSC_VER
 void bc_tester_set_max_vm(size_t amax_vm_kb) {
 #ifdef __linux__
 	max_vm_kb = (size_t)amax_vm_kb;
@@ -1262,6 +1267,9 @@ void bc_tester_set_max_vm(size_t amax_vm_kb) {
 	bc_tester_printf(bc_printf_verbosity_error, "Maximum virtual memory space setting is only implemented on Linux.");
 #endif
 }
+#ifndef _MSC_VER
+#pragma GCC diagnostic pop
+#endif // _MSC_VER
 
 void bc_tester_helper(const char *name, const char* additionnal_helper) {
 	bc_tester_printf(bc_printf_verbosity_info,
@@ -1416,7 +1424,13 @@ void bc_tester_add_suite(test_suite_t *suite) {
 	if (test_suite == NULL) {
 		test_suite = (test_suite_t **)malloc(10 * sizeof(test_suite_t *));
 	}
-	test_suite[nb_test_suites] = suite;
+	int insert_index = 0;
+	while(insert_index < nb_test_suites && test_suite[insert_index]->average_time >= suite->average_time ) ++insert_index;	// if suite->average_time == 0 => the new suite will be at the end.
+	if( insert_index < nb_test_suites) {// Need insertion
+		for(int move_index = nb_test_suites ; move_index >= insert_index + 1  ; --move_index)
+			test_suite[move_index] = test_suite[move_index-1];
+	}
+	test_suite[insert_index] = suite;
 	nb_test_suites++;
 	if ((nb_test_suites % 10) == 0) {
 		test_suite = (test_suite_t **)realloc(test_suite, (nb_test_suites + 10) * sizeof(test_suite_t *));
