@@ -43,4 +43,4 @@ static test_t container_tests[] = {
 };
 
 test_suite_t parser_test_suite = {"Parsing", NULL, NULL, NULL, NULL,
-							   sizeof(container_tests) / sizeof(container_tests[0]), container_tests};
+							   sizeof(container_tests) / sizeof(container_tests[0]), container_tests, 0};
